/****************************************************************************************************************************
  WiFiSocketBuffer.h - Library for Arduino WifiNINA module/shield.
  
  Forked and modified from WiFiNINA libarary https://www.arduino.cc/en/Reference/WiFiNINA
  to support other boards besides Nano-33 IoT, MKRWIFI1010, MKRVIDOR4000, etc.
  
  Built by Khoi Hoang https://github.com/khoih-prog/ESP8266_AT_WebServer
  Licensed under MIT license
  Version: 1.5.1
   
  Copyright (c) 2018 Arduino SA. All rights reserved.
  Copyright (c) 2011-2014 Arduino LLC.  All right reserved.

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  
  Version Modified By   Date      Comments
 ------- -----------  ---------- -----------
  1.5.0   K Hoang      27/03/2020 Initial coding to support other boards besides Nano-33 IoT, MKRWIFI1010, MKRVIDOR4000, etc.
                                  such as Arduino Mega, Teensy, SAMD21, SAMD51, STM32, etc
  1.5.1   K Hoang      22/04/2020 Add support to nRF52 boards, such as AdaFruit Feather nRF52832, nRF52840 Express, BlueFruit Sense, 
                                  Itsy-Bitsy nRF52840 Express, Metro nRF52840 Express, etc.                           
 *****************************************************************************************************************************/

#ifndef WiFiSocketBuffer_h
#define WiFiSocketBuffer_h

#include <stddef.h>
#include <stdint.h>

extern "C" {
  #include "utility/wl_definitions.h"
}

class WiFiSocketBufferClass {

public:
  WiFiSocketBufferClass();
  ~WiFiSocketBufferClass();

  void close(int socket);

  int available(int socket);
  int peek(int socket);
  int read(int socket, uint8_t* data, size_t length);

private:
  struct {
    uint8_t* data;
    uint8_t* head;
    int length;
  } _buffers[WIFI_MAX_SOCK_NUM];
};

extern WiFiSocketBufferClass WiFiSocketBuffer;

#endif    //WiFiSocketBuffer_h
